@@ -1,9 +1,9 @@
 package ArrayData::Test::Source::DBI;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-21'; # DATE
+our $DATE = '2021-04-25'; # DATE
 our $DIST = 'ArrayDataRoles-Standard'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use alias::module 'ArrayData::DBI';
 
@@ -22,7 +22,7 @@ ArrayData::Test::Source::DBI - Alias package for ArrayData::DBI
 
 =head1 VERSION
 
-This document describes version 0.003 of ArrayData::Test::Source::DBI (from Perl distribution ArrayDataRoles-Standard), released on 2021-04-21.
+This document describes version 0.004 of ArrayData::Test::Source::DBI (from Perl distribution ArrayDataRoles-Standard), released on 2021-04-25.
 
 =head1 HOMEPAGE
 
@@ -34,7 +34,7 @@ Source repository is at L<https://github.com/perlancar/perl-ArrayDataRoles-Stand
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-ArrayDataRoles-Standard/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=ArrayDataRoles-Standard>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
